<?php

namespace Drupal\o365_sharepoint_field\Form;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\CloseModalDialogCommand;
use Drupal\Core\Ajax\HtmlCommand;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\editor\Ajax\EditorDialogSave;
use Drupal\o365\GraphService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Our custom form used in the ckeditor plugin.
 */
class CkEditorDialog extends FormBase {

  /**
   * The graph service.
   *
   * @var \Drupal\o365\GraphService
   */
  protected $graphService;

  /**
   * Constructs a form object for the o365_sharepoint_field ckeditor plugin.
   *
   * @param \Drupal\o365\GraphService $graphService
   *   The graph service.
   */
  public function __construct(GraphService $graphService) {
    $this->graphService = $graphService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('o365.graph'));
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'o365_sharepoint_field_ckeditor_dialog_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    if (!empty($this->graphService->getCurrentUserId())) {
      // The default values are set directly from \Drupal::request()->request,
      // provided by the editor plugin opening the dialog.
      $user_input = $form_state->getUserInput();
      $input = $user_input['editor_object'] ?? [];

      $form['#tree'] = TRUE;
      $form['#attached']['library'][] = 'editor/drupal.editor.dialog';
      $form['#prefix'] = '<div id="o365-editor-dialog-form">';
      $form['#suffix'] = '</div>';

      // Everything under the "attributes" key is merged directly into the
      // generated link tag's attributes.
      $form['attributes']['href'] = [
        '#title' => $this->t('Link'),
        '#type' => 'textfield',
        '#default_value' => $input['href'] ?? '',
        '#description' => $this->t('Start typing to find content or paste a URL.'),
        '#autocomplete_route_name' => 'o365_sharepoint_field.autocomplete.ckeditor',
        '#weight' => 0,
        '#maxlength' => 6000,
      ];

      $form['actions'] = [
        '#type' => 'actions',
      ];

      $form['actions']['save_modal'] = [
        '#type' => 'submit',
        '#value' => $this->t('Save'),
        '#submit' => [],
        '#ajax' => [
          'callback' => '::submitForm',
          'event' => 'click',
        ],
      ];
    }
    else {
      $form['error'] = [
        '#markup' => $this->t('You can only use this functionality when logged in with a Microsoft account.'),
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $response = new AjaxResponse();

    if ($form_state->getErrors()) {
      unset($form['#prefix'], $form['#suffix']);
      $form['status_messages'] = [
        '#type' => 'status_messages',
        '#weight' => -10,
      ];
      $response->addCommand(new HtmlCommand('#o365-editor-dialog-form', $form));
    }
    else {
      $response->addCommand(new EditorDialogSave($form_state->getValues()));
      $response->addCommand(new CloseModalDialogCommand());
    }

    return $response;
  }

}
