<?php

namespace Drupal\o365_sharepoint_field\Plugin\CKEditorPlugin;

use Drupal\ckeditor\CKEditorPluginBase;
use Drupal\Core\Extension\ExtensionPathResolver;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\editor\Entity\Editor;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines the "SharePoint File Search" plugin, with a CKEditor.
 *
 * @CKEditorPlugin(
 *   id = "sharepoint",
 *   label = @Translation("Office 365 - Sharepoint File Search"),
 *   module = "o365_sharepoint_field"
 * )
 */
class SharePoint extends CKEditorPluginBase implements ContainerFactoryPluginInterface {

  /**
   * The path to the module.
   *
   * @var string
   */
  protected $modulePath = '';

  /**
   * This is the class constructor.
   *
   * @param array $configuration
   *   The configuration.
   * @param string $plugin_id
   *   The plugin id.
   * @param string $plugin_definition
   *   The plugin definition.
   * @param \Drupal\Core\Extension\ExtensionPathResolver $extensionPathResolver
   *   The extension path resolver.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ExtensionPathResolver $extensionPathResolver) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->modulePath = $extensionPathResolver->getPath('module', 'o365_sharepoint_field');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('extension.path.resolver')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFile() {
    return $this->modulePath . '/js/plugins/sharepoint/plugin.js';
  }

  /**
   * {@inheritdoc}
   *
   * NOTE: The keys of the returned array corresponds to the CKEditor button
   * names. They are the first argument of the editor.ui.addButton() or
   * editor.ui.addRichCombo() functions in the plugin.js file.
   */
  public function getButtons() {
    return [
      'Sharepoint' => [
        'label' => $this->t('SharePoint'),
        'image' => $this->modulePath . '/js/plugins/sharepoint/sharepoint.png',
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getConfig(Editor $editor) {
    return [];
  }

}
