<?php

namespace Drupal\o365_sso\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Settings form for the SSO module.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'o365_sso.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('o365_sso.settings');

    $form['link_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Link text'),
      '#default_value' => $config->get('link_text') ?? 'Login with Microsoft Office',
      '#description' => $this->t('This text will be used as the text in the link.'),
    ];

    $form['link_position'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show the Office login link on top of the login form'),
      '#default_value' => $config->get('link_position'),
      '#description' => $this->t('When disabled the link to the Office login will be shown on the bottom of the login form.'),
    ];

    $form['hide_login_form'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Hide the login form.'),
      '#default_value' => $config->get('hide_login_form'),
      '#description' => $this->t('When enabled nog login form will be shown. This can be overridden with ?show_login=true query parameter.'),
    ];

    $form['auto_redirect'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Automatically redirect users to the SSO login page.'),
      '#default_value' => $config->get('auto_redirect'),
      '#description' => $this->t('When enabled anonymous users that access the /user/login page will automatically be redirected to the SSO login page. Users that use "local" users (like admins) can use the /user/drupal_login path to use the normal Drupal login.'),
    ];

    $form['redirect_login_destination'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Redirect after login to destination URL'),
      '#description' => $this->t('After login users will be redirected to the destination page.'),
      '#default_value' => $config->get('redirect_login_destination'),
    ];

    $form['hide_user_fields'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Hide the username, password and e-mail fields from the user edit form.'),
      '#default_value' => $config->get('hide_user_fields'),
      '#description' => $this->t('This is only applicable to users that have been added with the Office 365 connector module.'),
    ];

    $form['only_existing_users'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Disable creating new users.'),
      '#default_value' => $config->get('only_existing_users'),
      '#description' => $this->t('When checked only existing users are able to log in (matched on e-mail address). A error will be shown to users without a Drupal user.'),
    ];

    $form['logout_office'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Log out from Office 365'),
      '#default_value' => $config->get('logout_office'),
      '#description' => $this->t('When checked a user will also automatically be logged out of office when logging out of Drupal.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('o365_sso.settings')
      ->set('auto_redirect', $form_state->getValue('auto_redirect'))
      ->set('link_text', $form_state->getValue('link_text'))
      ->set('link_position', $form_state->getValue('link_position'))
      ->set('redirect_login_destination', $form_state->getValue('redirect_login_destination'))
      ->set('hide_user_fields', $form_state->getValue('hide_user_fields'))
      ->set('hide_login_form', $form_state->getValue('hide_login_form'))
      ->set('only_existing_users', $form_state->getValue('only_existing_users'))
      ->set('logout_office', $form_state->getValue('logout_office'))
      ->save();
  }

}
